@@ -139,7 +139,7 @@ on_about (GSimpleAction *action,
                            "license-type", GTK_LICENSE_GPL_3_0,
                            "version", PACKAGE_VERSION,
                            "website", PACKAGE_URL,
-                           "issue-url", "https://gitlab.gnome.org/GNOME/gnome-logs/-/issues/new",
+                           "issue-url", "https://gitlab.gnome.org/GNOME/gnome-logs/-/issues/",
                            NULL);
 }
 
@@ -220,7 +220,7 @@ gl_application_startup (GApplication *application)
 
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
-    gtk_window_set_default_icon_name (PACKAGE_TARNAME);
+    gtk_window_set_default_icon_name ("org.gnome.Logs");
 }
 
 static void
