@@ -99,8 +99,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
     if (gl_journal_entry_get_command_line (entry))
     {
         gtk_label_set_text (GTK_LABEL (priv->comm_label), gl_journal_entry_get_command_line (entry));
-        gtk_widget_show (priv->comm_field_label);
-        gtk_widget_show (priv->comm_label);
+        gtk_widget_set_visible (priv->comm_field_label, TRUE);
+        gtk_widget_set_visible (priv->comm_label, TRUE);
     }
 
     now = g_date_time_new_now_local ();
@@ -115,15 +115,15 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
     if (gl_journal_entry_get_audit_session (entry))
     {
         gtk_label_set_text (GTK_LABEL (priv->audit_label), gl_journal_entry_get_audit_session (entry));
-        gtk_widget_show (priv->audit_field_label);
-        gtk_widget_show (priv->audit_label);
+        gtk_widget_set_visible (priv->audit_field_label, TRUE);
+        gtk_widget_set_visible (priv->audit_label, TRUE);
     }
 
     if (gl_journal_entry_get_kernel_device (entry))
     {
         gtk_label_set_text (GTK_LABEL (priv->device_label), gl_journal_entry_get_kernel_device (entry));
-        gtk_widget_show (priv->device_field_label);
-        gtk_widget_show (priv->device_label);
+        gtk_widget_set_visible (priv->device_field_label, TRUE);
+        gtk_widget_set_visible (priv->device_label, TRUE);
     }
 
     /* TODO: Give a user-friendly representation of the priority. */
@@ -166,8 +166,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->subject_label),
                                             str_message);
-                        gtk_widget_show (priv->subject_field_label);
-                        gtk_widget_show (priv->subject_label);
+                        gtk_widget_set_visible (priv->subject_field_label, TRUE);
+                        gtk_widget_set_visible (priv->subject_label, TRUE);
                     }
                 }
                 else
@@ -180,8 +180,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->subject_label),
                                             str);
-                        gtk_widget_show (priv->subject_field_label);
-                        gtk_widget_show (priv->subject_label);
+                        gtk_widget_set_visible (priv->subject_field_label, TRUE);
+                        gtk_widget_set_visible (priv->subject_label, TRUE);
                     }
 
                     g_free (str);
@@ -199,8 +199,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->definedby_label),
                                             str_message);
-                        gtk_widget_show (priv->definedby_field_label);
-                        gtk_widget_show (priv->definedby_label);
+                        gtk_widget_set_visible (priv->definedby_field_label, TRUE);
+                        gtk_widget_set_visible (priv->definedby_label, TRUE);
                     }
                 }
                 else
@@ -213,8 +213,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->definedby_label),
                                             str);
-                        gtk_widget_show (priv->definedby_field_label);
-                        gtk_widget_show (priv->definedby_label);
+                        gtk_widget_set_visible (priv->definedby_field_label, TRUE);
+                        gtk_widget_set_visible (priv->definedby_label, TRUE);
                     }
 
                     g_free (str);
@@ -238,8 +238,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
 
                         gtk_label_set_markup (GTK_LABEL (priv->support_label),
                                               str_link);
-                        gtk_widget_show (priv->support_field_label);
-                        gtk_widget_show (priv->support_label);
+                        gtk_widget_set_visible (priv->support_field_label, TRUE);
+                        gtk_widget_set_visible (priv->support_label, TRUE);
 
                         g_free (str_link);
                     }
@@ -260,8 +260,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
 
                         gtk_label_set_markup (GTK_LABEL (priv->support_label),
                                               str_link);
-                        gtk_widget_show (priv->support_field_label);
-                        gtk_widget_show (priv->support_label);
+                        gtk_widget_set_visible (priv->support_field_label, TRUE);
+                        gtk_widget_set_visible (priv->support_label, TRUE);
 
                         g_free (str_link);
                     }
@@ -281,8 +281,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->documentation_label),
                                             str_message);
-                        gtk_widget_show (priv->documentation_field_label);
-                        gtk_widget_show (priv->documentation_label);
+                        gtk_widget_set_visible (priv->documentation_field_label, TRUE);
+                        gtk_widget_set_visible (priv->documentation_label, TRUE);
                     }
                 }
                 else
@@ -295,8 +295,8 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
                     {
                         gtk_label_set_text (GTK_LABEL (priv->documentation_label),
                                             str);
-                        gtk_widget_show (priv->documentation_field_label);
-                        gtk_widget_show (priv->documentation_label);
+                        gtk_widget_set_visible (priv->documentation_field_label, TRUE);
+                        gtk_widget_set_visible (priv->documentation_label, TRUE);
                     }
 
                     g_free (str);
@@ -314,7 +314,7 @@ gl_event_view_detail_create_detail (GlEventViewDetail *detail)
         {
             gtk_label_set_text (GTK_LABEL (priv->detailed_message_label),
                                 str_field);
-            gtk_widget_show (priv->detailed_message_label);
+            gtk_widget_set_visible (priv->detailed_message_label, TRUE);
         }
 
         g_free (str_field);
@@ -329,24 +329,20 @@ gl_event_view_detail_popover_closed (GtkPopover *popover,
     GtkWidget *row;
     GtkWidget *category_label;
     GtkWidget *time_label;
-    GtkStyleContext *context;
 
-    row = gtk_popover_get_relative_to (popover);
+    row = gtk_widget_get_parent (GTK_WIDGET (popover));
 
-    context = gtk_widget_get_style_context (row);
-    gtk_style_context_remove_class (context, "popover-activated-row");
+    gtk_widget_remove_css_class (row, "popover-activated-row");
 
     category_label = gl_event_view_row_get_category_label (GL_EVENT_VIEW_ROW (row));
 
     if (category_label)
     {
-        context = gtk_widget_get_style_context (category_label);
-        gtk_style_context_add_class (context, "dim-label");
+        gtk_widget_add_css_class (category_label, "dim-label");
     }
 
     time_label = gl_event_view_row_get_time_label (GL_EVENT_VIEW_ROW (row));
-    context = gtk_widget_get_style_context (time_label);
-    gtk_style_context_add_class (context, "dim-label");
+    gtk_widget_add_css_class (time_label, "dim-label");
 }
 
 static void
