@@ -75,7 +75,7 @@ void gl_journal_set_matches (GlJournal *journal, GPtrArray *matches);
 void gl_journal_set_start_position (GlJournal *journal, guint64 until_timestamp);
 GArray * gl_journal_get_boot_ids (GlJournal *journal);
 GlJournalEntry * gl_journal_previous (GlJournal *journal);
-GlJournal * gl_journal_new (void);
+GlJournal * gl_journal_new (GPtrArray *files);
 gchar * gl_journal_get_boot_time (GlJournal *journal,
                                   const gchar *boot_match);
 
@@ -92,6 +92,8 @@ const gchar *           gl_journal_entry_get_pid                        (GlJourn
 const gchar *           gl_journal_entry_get_gid                        (GlJournalEntry *entry);
 const gchar *           gl_journal_entry_get_systemd_unit               (GlJournalEntry *entry);
 const gchar *           gl_journal_entry_get_executable_path            (GlJournalEntry *entry);
+gboolean                gl_journal_entry_get_display_time_label         (GlJournalEntry *entry);
+void                    gl_journal_entry_set_display_time_label         (GlJournalEntry *entry, gboolean value);
 
 G_END_DECLS
 
